package Period;

use strict;
use warnings;

use DateTime;

sub parseDateToRef
{
	my ($date) = @_;

	my $ref = {};

	$ref->{'year'} = substr ($date,  0, 4);
	$ref->{'mon'}  = substr ($date,  5, 2);
	$ref->{'mday'} = substr ($date,  8, 2);
	$ref->{'hour'} = substr ($date, 11, 2);
	$ref->{'min'}  = substr ($date, 14, 2);
	$ref->{'sec'}  = substr ($date, 17, 2);

	return $ref;
}

sub getTimeFromDate
{
	my ($date) = @_;

	my $ref = parseDateToRef ($date);

	my $dt = DateTime->new(
    	year       => $ref->{'year'},
    	month      => $ref->{'mon'},
    	day        => $ref->{'mday'},
    	hour       => $ref->{'hour'},
    	minute     => $ref->{'min'},
    	second     => $ref->{'sec'},
    	time_zone  => 'America/New_York',
	);

	return $dt->epoch ();
}

sub findMidnightPlusOne
{
	my ($time) = @_;

	my $dt = DateTime->from_epoch (
    	epoch      => $time,
    	time_zone  => 'America/New_York',
	);

	my $xsec = $dt->sec ();
	my $xmin = $dt->min ();
	my $xhour = $dt->hour ();
	my $xmon  = $dt->mon();
	my $xyear = $dt->year ();
	my $xwday = $dt->wday ();
	my $xmday = $dt->mday ();

	$time -= ($xhour * 3600);
	$time -= ($xmin * 60);

	if ($xsec > 1)
	{
		$xsec --;

		$time -= $xsec;
	}
	elsif ($xsec == 1)
	{
	}
	else
	{
		$time ++;
	}

    # check our work

	my $dt1 = DateTime->from_epoch (
    	epoch      => $time,
    	time_zone  => 'America/New_York',
	);

    # we may have overshot or undershot
    # midnight because of Daylight Savings
    # We would only over or under shoot by
    # at most 2 hours.

	my $ywday = $dt1->wday ();
	my $yhour = $dt1->hour ();
    my $ymin = $dt1->min ();
    my $ysec = $dt1->sec ();

    if ($ywday != $xwday)
    {
        # we overshot midnight, bring us back

        my $xtime;

        $xtime  = $yhour * 3600;
        $xtime += $ymin * 60;
        $xtime += $ysec;

        $xtime = 86400 - $xtime;

        $time += ($xtime + 1);

	    $dt1 = DateTime->from_epoch (
            epoch      => $time,
            time_zone  => 'America/New_York',
        );

        $ywday = $dt1->wday ();
        $yhour = $dt1->hour ();
        $ymin = $dt1->min ();
        $ysec = $dt1->sec ();

        if ($ywday != $xwday ||
            $yhour != 0 ||
            $ymin  != 0 ||
            $ysec  != 1)
        {
            die "The Daylight Savings overshoot has run off the tracks";
        }
    }

    # check to see if we have undershot midnight

    if ($yhour != 0 ||
        $ymin  != 0 ||
        $ysec  != 1)
    {
        my $xtime;

        $xtime  = $yhour * 3600;
        $xtime += $ymin * 60;
        $xtime += $ysec;

        $time -= $xtime;
        $time ++;

	    $dt1 = DateTime->from_epoch (
            epoch      => $time,
            time_zone  => 'America/New_York',
        );

        $ywday = $dt1->wday ();
        $yhour = $dt1->hour ();
        $ymin = $dt1->min ();
        $ysec = $dt1->sec ();

        if ($ywday != $xwday ||
            $yhour != 0 ||
            $ymin  != 0 ||
            $ysec  != 1)
        {
            die "The Daylight Savings undershoot has run off the tracks ($ywday,$yhour,$ymin,$ysec)";
        }
    }

	return ($time, $xwday);
}

sub convertTimeToDate
{
	my ($time) = @_;

	$time = time () if !defined $time;

	my $dt = DateTime->from_epoch (
    	epoch      => $time,
    	time_zone  => 'America/New_York',
	);

	my $sdate = sprintf ("%04d-%02d-%02d %02d:%02d:%02d",
		$dt->year (),
		$dt->mon (),
		$dt->mday (),
		$dt->hour (),
		$dt->min (),
		$dt->sec ());

	return $sdate;
}

sub getEpochFromEastern
{
	my ($date) = @_;

	my ($year, $mon, $mday, $hour, $min, $sec) = ($date =~ m/(\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2}):(\d{2})/);

	return if (!defined $year && !defined $sec);

	my $dt = DateTime->new(
    	year       => $year,
    	month      => $mon,
    	day        => $mday,
    	hour       => $hour,
    	minute     => $min,
    	second     => $sec,
    	time_zone  => 'America/New_York',
	);

	return $dt->epoch ();
}

sub mapToLocalTimeWday
{
	my ($wday) = @_;

	# LocalTime 0 Sunday ... 6 Saturday
	# DateTime  1 Monday ... 7 Sunday	

	my $xwday = $wday;
	$xwday = 0 if ($xwday == 1);

	return $xwday;
}

1;

__END__

