package TimeFrame;

use strict;
use warnings;

use Common;
use Period;

sub new
{
	my ($class) = @_;

	my $self = {};

	bless $self, $class;

	$self->SUPER::initialize ();
	$self->initialize ();

	return $self;
}

sub initialize
{
	my ($self) = @_;

	$self->{'current_timeframe'} = undef;
	$self->{'next_timeframe'} = undef;

	return $self;
}

sub calc_currentTimeFrame
{
	my ($self, $minute_timeframe) = @_;

	return;
}

sub calc_nextTimeFrame
{
	my ($self, $current_timeframe) = @_;

	return;
}

sub updateCandle
{
	my ($self, $candle_ref) = @_;

	if (!defined $self->{'accum_candle_ref'})
	{
		$self->{'accum_candle_ref'} = Common::copyHashRef ($candle_ref);
		$self->{'accum_candle_ref'}->{'Date'} = $self->{'current_timeframe'};
		return;
	}

	$self->{'accum_candle_ref'}->{'Close'} = $candle_ref->{'Close'};

	$self->{'accum_candle_ref'}->{'High'} = $candle_ref->{'High'} if ($self->{'accum_candle_ref'}->{'High'} < $candle_ref->{'High'});
	$self->{'accum_candle_ref'}->{'Low'} = $candle_ref->{'Low'} if ($self->{'accum_candle_ref'}->{'Low'} > $candle_ref->{'Low'});
}

sub recordCandle
{
	my ($self) = @_;

	$self->{'recorded_candle_ref'} = $self->{'accum_candle_ref'};
	delete $self->{'accum_candle_ref'};
}

# The candle ref needs to have the following entries
# Date, in the form 2014/11/26 11:29:00,
# Open, High, Low, Close

sub incomingMinuteCandle
{
	my ($self, $candle_ref) = @_;

	my $minute_timeframe = $candle_ref->{'Date'};

	$minute_timeframe = Common::trim ($minute_timeframe);

	if ($self->{'name'} eq "Minute")
	{
		$self->{'accum_candle_ref'} = $candle_ref;
		$self->recordCandle ();
		return;
	}

	$self->{'current_timeframe'} = $self->calc_currentTimeFrame ($minute_timeframe) if !defined $self->{'current_timeframe'};
	$self->{'next_timeframe'}    = $self->calc_nextTimeFrame ($self->{'current_timeframe'}) if !defined $self->{'next_timeframe'};

	die "Out of sequence" if $minute_timeframe lt $self->{'current_timeframe'};

	if ($minute_timeframe ge $self->{'next_timeframe'})
	{
		$self->recordCandle ();

		$self->{'current_timeframe'} = $self->calc_currentTimeFrame ($minute_timeframe);
		$self->{'next_timeframe'}    = $self->calc_nextTimeFrame ($self->{'current_timeframe'});
	}

	$self->updateCandle ($candle_ref);

	return;
}

sub calc_prevTimeFrame
{
	my ($self, $minute_timeframe) = @_;

	my $current_timeframe = $self->calc_currentTimeFrame ($minute_timeframe);

	# now subtract a minute from that

	my $time = Period::getTimeFromDate ($current_timeframe);	
	$time -= 60; # subtract a minute

	my $prev_timeframe = $self->calc_currentTimeFrame (Period::convertTimeToDate ($time));

	return $prev_timeframe;
}

sub getStatus
{
	my ($self) = @_;

	my $ref;
	my $output = "UNKNOWN";

	$ref = $self->{'accum_candle_ref'};
	$ref = $self->{'recorded_candle_ref'} if (exists $self->{'recorded_candle_ref'});

	if (defined $ref)
	{
		my $date = $ref->{'Date'};
        my $current_timeframe = $self->calc_currentTimeFrame ($date);

		$output = sprintf ("%8.8s %30.30s %8.4f %8.4f %8.4f %8.4f",
			$self->{'name'},
			$current_timeframe,
			$ref->{'Open'},
			$ref->{'High'},
			$ref->{'Low'},
			$ref->{'Close'});
	}

	return $output;
}

1;

__END__

