package TimeFrame::Weekly;

use strict;
use warnings;

use parent 'TimeFrame';

use Common;
use Period;

sub new
{
	my ($class) = @_;

	my $self = {};

	bless $self, $class;

	$self->SUPER::initialize ();
	$self->initialize ();

	return $self;
}

sub initialize
{
	my ($self) = @_;

	$self->{'name'} = "Weekly";

	return $self;
}

sub calc_currentTimeFrame
{
	my ($self, $minute_timeframe) = @_;

	my $ywday;
	my $time = Period::getTimeFromDate ($minute_timeframe);
	($time, $ywday) = Period::findMidnightPlusOne ($time);

	# map from 1 = Monday .. 7 Sunday to
	# 0 Sunday ... 6 is Saturday

	my $xywday = Period::mapToLocalTimeWday ($ywday);

	$time -= ($xywday * 86400);
	($time, $ywday) = Period::findMidnightPlusOne ($time);

	if ($ywday == 6) # Sat
	{
		$time += 86400;
		($time, $ywday) = Period::findMidnightPlusOne ($time);
	}
	elsif ($ywday != 7) # Not Sunday
	{
		while ($ywday != 7)
		{
			$time -= 10800; # offset it some more just to be sure
			($time, $ywday) = Period::findMidnightPlusOne ($time);
		}
	}

	# make it midnight not midnight plus 1
	$time --;

	my $output_timeframe = Period::convertTimeToDate ($time);

	return $output_timeframe;
}

sub calc_nextTimeFrame
{
	my ($self, $current_timeframe) = @_;

	my $ywday;
	my $time = Period::getTimeFromDate ($current_timeframe);
	($time, $ywday) = Period::findMidnightPlusOne ($time);

	$time += (7 * 86400) + 10800;

	($time, $ywday) = Period::findMidnightPlusOne ($time);

	$time --;

	my $next_timeframe = Period::convertTimeToDate ($time);
	# daylights savings can be problematic
	my $ref = Period::parseDateToRef ($next_timeframe);

	$next_timeframe = $ref->{'year'} . "-" . $ref->{'mon'} . "-" . $ref->{'mday'} . " 00:00:00";

	return $next_timeframe;
}

1;

__END__

