
use strict;
use warnings;

no warnings 'redefine';

use Test::More tests =>  7;

use Common;
use Period;

use Data::Dumper;
use File::Slurp;

my $xtime = time ();
my $xTS = Period::convertTimeToDate ($xtime);

# 01234567890123456789
# 2015-01-01 01:01:01

my $year = substr ($xTS,  0, 4);
my $mon  = substr ($xTS,  5, 2);
my $mday = substr ($xTS,  8, 2);
my $hour = substr ($xTS, 11, 2);
my $min  = substr ($xTS, 14, 2);
my $sec  = substr ($xTS, 17, 2);

my $xdate = $year . "-" . $mon . "-" . $mday . " " . $hour . ":" . $min . ":" . $sec;

my $expected = {};

$expected->{'year'} = $year;
$expected->{'mon'} = $mon;
$expected->{'mday'} = $mday;
$expected->{'hour'} = $hour;
$expected->{'min'} = $min;
$expected->{'sec'} = $sec;

my $got = Period::parseDateToRef ($xdate);

is_deeply ($got, $expected, "Parse worked");

my $ytime = Period::getTimeFromDate ($xdate);

is ($ytime, $xtime, "getTimeFromDate is correct");

my $xmidnight = $year . "-" . $mon . "-" . $mday . " " . "00:00:01";
my $xmidnight_time = Period::getTimeFromDate ($xmidnight);

my ($ymidnight_time, $xwday) = Period::findMidnightPlusOne ($xtime);

is ($ymidnight_time, $xmidnight_time, "findMidnightPlusOne - time is correct");

my $dt1 = DateTime->from_epoch (
	epoch      => $xmidnight_time,
	time_zone  => 'America/New_York',
);

my $zwday = $dt1->wday ();

is ($xwday, $zwday, "findMidnightPlusOne - wday is correct");

my $tdate = Period::convertTimeToDate ($xtime);

is ($tdate, $xdate, "convertTimeToDate is correct");

my $problem_001_ts = "2014-11-02 15:03:00 ";
my $problem_001_time = Period::getTimeFromDate ($problem_001_ts);
my ($problem_001_midnight, $problem_001_wday) = Period::findMidnightPlusOne ($problem_001_time);

my $response_001_ts = Period::convertTimeToDate ($problem_001_midnight);

is ($response_001_ts, "2014-11-02 00:00:01", "Found midnight on Fallback");

my $problem_002_ts = "2014-03-09 15:03:00 ";
my $problem_002_time = Period::getTimeFromDate ($problem_002_ts);
my ($problem_002_midnight, $problem_002_wday) = Period::findMidnightPlusOne ($problem_002_time);

my $response_002_ts = Period::convertTimeToDate ($problem_002_midnight);

is ($response_002_ts, "2014-03-09 00:00:01", "Found midnight on Spring Ahead");

1;

